<!DOCTYPE html>
<html lang="id">

<head>
    <meta charset="utf-8">
    <meta name="description"
        content="Institut Agama Islam Sahid (INAIS) Bogor merupakan institusi pendidikan tinggi berbasis Islam yang berlokasi di Bogor. INAIS menawarkan berbagai program studi, termasuk S1 Perbankan Syariah, Manajemen Bisnis Syariah, Pendidikan Guru Madrasah Ibtidaiyah, Manajemen Pendidikan Islam, dan Komunikasi dan Penyiaran Islam, baik untuk kelas reguler maupun kelas khusus. INAIS juga menyediakan program pascasarjana S2 Ekonomi Syariah dengan biaya terjangkau untuk mendukung pengembangan keilmuan berbasis nilai-nilai Islam." />
    <meta name="keywords"
        content="INAIS, Institut Agama Islam Sahid Bogor, kuliah di Bogor, kampus murah di Bogor, universitas swasta unggulan di Bogor, jurusan Institut Agama Islam Sahid Bogor, daftar online INAIS, biaya kuliah INAIS, program studi di INAIS, kelas karyawan INAIS, kampus swasta terbaik di Bogor
        STIKes Bogor Husada, STIKes Mitra RIA Husada, universitas kesehatan di Bogor, kuliah kesehatan di Bogor, STIKes terbaik di Bogor,
        Universitas Pakuan, Universitas Ibn Khaldun Bogor, Universitas Djuanda Bogor, universitas di Bogor, kampus terbaik di Bogor, kuliah jurusan kesehatan di Bogor,
        Universitas Nasional PASIM Bogor, Universitas Muhammadiyah Bogor Raya, universitas swasta murah di Bogor, universitas unggulan di Bogor,
        Sekolah Tinggi Agama Islam (STAI) Al Hikmah, Sekolah Tinggi Agama Islam (STAI) Yasni, perguruan tinggi Islam di Bogor, kuliah jurusan agama Islam, kampus Islam unggulan di Bogor,
        Kuliah S1 di Bogor, jurusan terfavorit di Bogor, kampus swasta kompetitif di Bogor,
        Universitas Esa Unggul Bogor, Universitas Ibnu Khaldun Bogor, kampus Islam di Bogor, kuliah murah jurusan agama Islam,
        edunitas">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />

    <title><?php echo $__env->yieldContent('title'); ?> &mdash; Institut Agama Islam Sahid Bogor (Kelas Karyawan)</title>
    <meta property="og:title" content="Institut Agama Islam Sahid Bogor (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="https://inais.info">
    <meta property="og:image" content="https://inais.info/images/background/hero1.png">
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description"
        content="Institut Agama Islam Sahid Bogor adalah pilihan tepat untuk pendidikan tinggi di Bogor. Dengan berbagai program studi unggulan seperti S1 Manajemen Pendidikan Islam, S1 Pendidikan Guru Madrasah Ibtidaiyah, S1 Komunikasi dan Penyiaran Islam, S1 Perbankan Syariah, dan S1 Manejemen Bisnis Syariah, serta Program Pascasarjana yaitu S2 Ekonomi Syariah. 
INAIS merupakan kampus yang menawarkan pendidikan berkualitas yang berorientasi pada pengembangan keilmuan dan moral. Didukung oleh fasilitas modern, dosen profesional, serta suasana akademik yang kondusif, INAIS menjadi destinasi utama bagi calon mahasiswa yang mencari pendidikan berbasis nilai-nilai Islam. Lokasinya yang strategis di kawasan Bogor menjadikan kampus ini pilihan favorit bagi mahasiswa lokal dan luar daerah.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title"
        content="Institut Agama Islam Sahid Bogor | Institut Agama Islam Sahid Bogor (Kelas Karyawan)">
    <meta name="twitter:description"
        content="Institut Agama Islam Sahid Bogor menawarkan solusi dengan fleksibilitas waktu melalui kelas reguler dan kelas karyawan. Program studi unggulan seperti Pendidikan Agama Islam, Manajemen Pendidikan Islam, dan Hukum Keluarga Islam dirancang khusus untuk mendukung pengembangan karier Anda. Dengan biaya kuliah yang terjangkau dan fasilitas pembelajaran yang modern, INAIS adalah pilihan terbaik untuk meraih pendidikan tinggi tanpa mengorbankan pekerjaan.">
    <meta name="twitter:domain" content="https://inais.info/">
    <meta name="twitter:image:src" content="https://inais.info/images/background/hero1.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="Institut Agama Islam Sahid Bogor | Kuliah Karyawan K2" />
    <meta name="msapplication-TileColor" content="#9E2A61" />
    <meta name="theme-color" content="#9E2A61" />

    <link rel="apple-touch-icon" sizes="57x57" href="<?php echo e(asset('images/favicons/apple-icon-57x57.png')); ?>">
    <link rel="apple-touch-icon" sizes="60x60" href="<?php echo e(asset('images/favicons/apple-icon-60x60.png')); ?>">
    <link rel="apple-touch-icon" sizes="72x72" href="<?php echo e(asset('images/favicons/apple-icon-72x72.png')); ?>">
    <link rel="apple-touch-icon" sizes="76x76" href="<?php echo e(asset('images/favicons/apple-icon-76x76.png')); ?>">
    <link rel="apple-touch-icon" sizes="114x114" href="<?php echo e(asset('images/favicons/apple-icon-114x114.png')); ?>">
    <link rel="apple-touch-icon" sizes="120x120" href="<?php echo e(asset('images/favicons/apple-icon-120x120.png')); ?>">
    <link rel="apple-touch-icon" sizes="144x144" href="<?php echo e(asset('images/favicons/apple-icon-144x144.png')); ?>">
    <link rel="apple-touch-icon" sizes="152x152" href="<?php echo e(asset('images/favicons/apple-icon-152x152.png')); ?>">
    <link rel="apple-touch-icon" sizes="180x180" href="<?php echo e(asset('images/favicons/apple-icon-180x180.png')); ?>">
    <link rel="icon" type="image/png" sizes="192x192"
        href="<?php echo e(asset('images/favicons/android-icon-192x192.png')); ?>">
    <link rel="icon" type="image/png" sizes="32x32" href="<?php echo e(asset('images/favicons/favicons-32x32.png')); ?>">
    <link rel="icon" type="image/png" sizes="96x96" href="<?php echo e(asset('images/favicons/favicons-96x96.png')); ?>">
    <link rel="icon" type="image/png" sizes="16x16" href="<?php echo e(asset('images/favicons/favicons-16x16.png')); ?>">
    <link rel="manifest" href="images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">
    <!--verifikasi-->
    <meta name="google-site-verification" content="JFYwSdAhJ5cnJwZVYYYobb52XX3nISzQ98y5Q2ys9Hg" />
    


    
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@400;600&family=DM+Sans:wght@400;700&display=swap" rel="stylesheet">
    <link href="<?php echo e(asset('css/app.css')); ?>" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css" />
    <link href="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.css" rel="stylesheet">

    <style>
        /* FIX TOTAL DOUBLE SCROLLBAR */
        html {
            overflow: -moz-scrollbars-none;
            -ms-overflow-style: none; /* IE and Edge */
            scrollbar-width: none; /* Firefox (untuk menghilangkan scrollbar di level html) */
            height: 100%;
            margin: 0;
            padding: 0;
        }

        html::-webkit-scrollbar {
            display: none; /* Chrome, Safari, Opera */
        }

        body {
            /* Scrollbar hanya boleh ada di sini */
            overflow-y: auto; 
            overflow-x: hidden !important;
            min-height: 100%;
            margin: 0;
            padding: 0;
            position: relative;
            -webkit-overflow-scrolling: touch;
        }

        /* Container utama tidak boleh punya scroll sendiri */
        main {
            overflow: visible !important;
            display: block;
            width: 100%;
        }

        /* Mencegah tombol WA merusak lebar layar */
        .whatsapp-button-container {
            pointer-events: none;
        }
        .whatsapp-button-container a, .whatsapp-button-container div {
            pointer-events: auto;
        }
    </style>

    <?php echo $__env->yieldPushContent('prpend-style'); ?>
    <?php echo $__env->yieldPushContent('addon-style'); ?>
</head>

<body class="antialiased">

    
    <?php echo $__env->make('Frontend.Template.navbar', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>

    
    <main>
        <?php echo $__env->yieldContent('content'); ?>
    </main>

    
    <div class="whatsapp-button-container fixed flex flex-row items-center bottom-4 right-4 z-[9999] md:bottom-10 md:right-10">
        <div style="color:#fff;"
            class="slide-text whatsapp-button hidden md:flex overflow-hidden shadow-2xl transition-all duration-500 ease-in-out bg-[#40C351] h-[45px] items-center px-4 font-poppins text-white rounded-full mr-2">
            <span class="whatsapp-button-text text-sm">ingin bertanya ? yuk di click !</span>
        </div>

        <a href="https://wa.me/6289504586704?text=Halo%20Admin%2C%20saya%20mau%20bertanya" 
            target="_blank" rel="noopener noreferrer" class="hover:scale-110 transition-transform">
            <img src="<?php echo e(asset('images/logo/wa.jpg')); ?>" alt="WhatsApp" class="w-12 h-12 md:w-[70px] md:h-[70px] rounded-full shadow-lg">
        </a>
    </div>

    
    <?php echo $__env->make('Frontend.Template.footer', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>

    
    <script src="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.js"></script>
    <script src="<?php echo e(asset('./js/app.js')); ?>"></script>

    <?php echo $__env->yieldPushContent('prpend-script'); ?>
    <?php echo $__env->yieldPushContent('addon-script'); ?>

    <script>
        AOS.init({ once: true });
        // Disable Right Click
        document.addEventListener('contextmenu', function(e) { e.preventDefault(); });
    </script>
</body>
</html><?php /**PATH /home/edunesiaserver/public_html/K2/WEB_KAMPUS/WEB_TEMPLATE/Ungu-Kuning/resources/views/Frontend/Layouts/app.blade.php ENDPATH**/ ?>