<?php $__env->startSection('title', 'Sejarah'); ?>


<?php $__env->startSection('content'); ?>
<br><br>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => 'Sejarah  '.e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia').'','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'Sejarah Singkat']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        

        <!-- Konten Teks -->
        <div data-aos="fade-up" class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px]">
            <p class="text-justify" style="font-size: 14px;">

Cikal bakal berdirinya Sekolah Tinggi Ilmu Sosial dan Ilmu Politik (STISIPOL) Candradimuka adalah Akademi Publisistik Candradimuka Palembang (APCP) yang didirikan oleh Yayasan Seni dan Ilmu Pengetahuan (YASIP) pada tahun 1967. Sejalan dengan perkembangan pendidikan di tanah air maka pada tahun 1979 Akademi Publisistik Candradimuka Palembang (APCP) berubah nama menjadi Sekolah Tinggi Ilmu Sosial (STIS) Candradimuka dengan dua jurusan yaitu: Jurusan Ilmu Komunikasi dan Ilmu Administrasi.

Selanjutnya pada tahun 1985 Sekolah Tinggi Ilmu Sosial (STIS) Candradimuka berubah nama menjadi Sekolah Tinggi Ilmu Sosial dan Ilmu Politik (STISIPOL) Candradimuka, yang terdiri dari empat jurusan yaitu: Jurusan Ilmu Komunikasi, Jurusan Ilmu Administrasi Negara, Jurusan Ilmu Kesejahteraan Sosial dan Jurusan Ilmu Politik.

Pada tahun 2005 Sekolah Tinggi Ilmu Sosial dan Ilmu Politik (STISIPOL) Candradimuka mulai melakukan regenerasi pada berbagai bidang. Melalui rapat senat STISIPOL Candradimuka, Dr. Hj. Lishapsari Prihatini, M.Si. terpilih menjadi Ketua STISIPOL Candradimuka dengan perolehan suara yang sangat signifikan.

Perubahan besar dilakukan oleh Ketua baru STISIPOL Candradimuka Dr. Hj. Lishapsari Prihatini, M.Si. Awal perubahan besar tersebut mulai dari penataan kembali gedung perkuliahan, perekrutan dosen berbagai disiplin ilmu baik akademis maupun praktisi sebagai tenaga pengajar dan fasilitas pendukung perkuliahan lainnya. Langkah tersebut dilakukan terus-menerus untuk menjaga komitmen STISIPOL Candradimuka demi menghasilkan sarjana-sarjana yang berkualitas, profesional dan kredibel sesuai dengan kompetensi disiplin ilmu massing-masing.Pada tahun 2006 STISIPOL Candradimuka membuka program pascasarjana (S2) Magister Administrasi Publik/MAP.
                
            </p>

        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">
                SEGERA DAFTAR
                </h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
            Bergabunglah bersama  <?php echo e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia'); ?> dan Bangun Wawasan, Bentuk Karakter, Jadilah Pembawa Perubahan!
        </p>
            <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/pendaftaran']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>DAFTAR SEKARANG <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /home/edunesiaserver/public_html/K2/WEB_KAMPUS/WEB_TEMPLATE/Merah-Kuning/resources/views/Frontend/sejarah.blade.php ENDPATH**/ ?>