<div class="md:h-[827px] h-auto flex flex-col items-center md:flex-row justify-center md:gap-x-[100px] py-[100px] md:py-[100px] px-4 md:px-0 bg-cover bg-no-repeat bg-right md:bg-center"
    style="background-image: url('<?php echo e(asset('./images/background/bg-sambutan.png')); ?>');">
    <div class="flex justify-center md:justify-start w-full md:w-auto flex-col items-center">
    <img src="<?php echo e(asset('./images/sambutan/sambutan.png')); ?>" data-aos="fade-up"
        class="h-auto md:w-[1000px] w-[300px] md:h-[500px] max-w-[450px]" style="border-radius:25px;" alt="<?php echo e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia'); ?>">
    <p style="padding-top: 20px; font-size: 14px; color: #fff; text-align: center; font-family: 'Poppins', sans-serif;">
        <!-- <b>Dendi Afrizal, S.AB., M.Ak, </b> -->
    </p>
</div>
    <div class="flex flex-col md:items-start justify-center items-center w-full md:w-[40%] w-[100%] mt-4 md:mt-0"
        data-aos="fade-up">
        <?php if (isset($component)) { $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSection::class, ['subtext' => ' SAMBUTAN KETUA '.e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia').'','subtextColor' => '#fff','title' => '','titleColor' => '#fff']); ?>
<?php $component->withName('header-section'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe)): ?>
<?php $component = $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe; ?>
<?php unset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe); ?>
<?php endif; ?>
        <p class="text-justify font-dmsans mb-4 font-inter text-sm md:text-base  normal-case w-[80%]" style="color:#fff" >
Semoga kita semua mendapat limpahan rahmat dari Allah SWT. Aamiin yarobbal alamin. Yayasan Seni dan Ilmu Pengetahuan atau YASIP sejak awal berdiri berdasarkan Akte Notaris Aminus No. 25 tahun 1967 dengan Akademi Publisistik Candradimuka Palembang atau APCP bertekad ingin melahirkan para sarjana bidang publisistik, yang dikenal dengan sebutan wartawan, terus menerus memacu STISIPOL Candradimuka agar mencetak para sarjana bidang Ilmu Komunikasi, Ilmu Administrasi Negara, Ilmu Kesejahteraan Sosial, Ilmu Politik, Program Pascasarjana Magister Administrasi Publik dan Magister Ilmu Komunikasi.
Derap langkah kemajuan perjalanan dari APCP menjadi STISIPOL Candradimuka seperti sekarang ini merupakan bukti keseriusan kami memberikan makna kepada bangsa dan negara dalam peningkatan kualitas sumber daya manusia Indonesia yang berakhlak mulia dan memberi manfaat yang lebih baik kepada masyarakat.
YASIP selalu memberi bimbingan dan arahan agar STISIPOL Candradimuka terus menjaga eksistensi dalam penciptaan kader pemimpin bangsa melalui setiap jurusan yang dibuka. YASIP juga sangat bangga bahwa ribuan alumni STISIPOL Candradimuka ini berhasil mengaktualisasikan diri mengabdi kepada masyarakat melalui profesinya masing-masing.
Mari kita terus semangat dalam memajukan peran masing-masing sebagai insan pembangunan secara pribadi maupun berperan dan bertanggungjawab membesarkan STISIPOL Candradimuka secara institusional serta memberikan manfaat yang berguna bagi bangsa dan negara kesatuan Republik Indonesia.
        </p>
        
<a href="/sejarah-singkat" class="bg-yellow-400 hover:bg-primary font-medium py-2 px-3 rounded-md text-sm transition-all  text-center text-white">
    BACA SELENGKAPNYA
</a>
    </div>
</div>
<?php /**PATH /home/edunesiaserver/public_html/K2/WEB_KAMPUS/WEB_TEMPLATE/Merah-Kuning/resources/views/Frontend/landingpage/sambutan-section.blade.php ENDPATH**/ ?>