<?php $__env->startSection('title', 'Tracer Study Berhasil'); ?>



<?php $__env->startSection('content'); ?>
<br><br>
<div class="py-20 bg-gray-50 min-h-screen flex items-center">
    <div class="container mx-auto px-4">
        <div class="max-w-lg mx-auto bg-white rounded-lg shadow-lg p-8 text-center">
            <div class="w-20 h-20 bg-green-100 rounded-full flex items-center justify-center mx-auto mb-6">
                <svg class="w-10 h-10 text-green-500" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M5 13l4 4L19 7"></path>
                </svg>
            </div>
            <h2 class="text-2xl font-poppins font-bold text-gray-800 mb-4">Terima Kasih!</h2>
            <p class="text-gray-600 font-dmsans mb-6">
                Data Tracer Study Anda berhasil kami terima. Terima kasih atas partisipasi Anda dalam membantu meningkatkan kualitas <?php echo e($settings['nama kampus'] ?? 'kampus kami'); ?>.
            </p>
            <a href="<?php echo e(route('fe-home')); ?>" class="inline-block bg-primary text-white px-6 py-3 rounded-lg hover:bg-accent transition">
                Kembali ke Beranda
            </a>
        </div>
    </div>
</div>
<?php $__env->stopSection(); ?>
<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /home/edunesiaserver/public_html/K2/WEB_KAMPUS/JAKARTA/ISTA-ALKAMAL/WEB/resources/views/Frontend/tracer-success.blade.php ENDPATH**/ ?>