<!DOCTYPE html>
<html lang="id">

<head>
    <meta charset="utf-8">
    <meta name="description" content="STISIPOL Candradimuka adalah perguruan tinggi yang menawarkan program S1 Kesejahteraan Sosial & Ilmu Politik, S1 Ilmu Komunikasi & Ilmu Administrasi Negara. Dengan biaya kuliah yang terjangkau, mulai dari 350 ribu per bulan, kami berkomitmen untuk memberikan pendidikan berkualitas dengan kurikulum yang relevan dan berbasis praktik. Dapatkan pengalaman belajar yang mendukung pengembangan akademik dan profesional Anda di lingkungan yang kondusif. Bergabunglah dengan STISIPOL Candradimuka dan wujudkan masa depan yang lebih cerah bersama kami.">
    <meta name="keywords" content="edunitas, Kelas karyawan, Kuliah karyawan, STISIPOL Candradimuka, kampus STISIPOL Candradimuka , biaya kuliah kampus STISIPOL Candradimuka , biaya kuliah, kelas sabtu, akreditasi STISIPOL Candradimuka, kelas karyawan terjangkau Palembang , S1 Kesejahteraan Sosial & Ilmu Politik, S1 Ilmu Komunikasi & Ilmu Administrasi Negara, kampus murah Di Palembang , kampus Di Palembang , biaya kuliah, kelas sabtu, akreditasi STISIPOL Candradimuka ,
     Kampus Kelas Karyawan Di Palembang , Kuliah Sambil Kerja Di Palembang , Universitas Terbaik di Palembang  untuk Karyawan, Biaya Kuliah Terjangkau di Palembang , Universitas Kelas Sabtu Minggu Di Palembang , Akreditasi Universitas Di Palembang ,Perguruan Tinggi Swasta Murah di Palembang , Program S1 Kesejahteraan Sosial & Ilmu Politik, Program S1 Ilmu Komunikasi & Ilmu Administrasi Negara ,  Kampus Swasta Terbaik Palembang , Universitas Murah  Di Palembang  terakreditasi Baik,
     Kampus Terjangkau di Palembang  untuk Karyawan, , Kuliah dengan Biaya Mulai Rp 300.000 di Palembang  , Universitas dengan Kelas Online Palembang , Kampus Swasta Kelas Sabtu Minggu di Palembang , Biaya Kuliah  Sarjana Murah di Palembang , Biaya Kuliah S1 Murah di Palembang  , Kampus dengan Program Studi Lengkap di Palembang " />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    
    <title><?php echo $__env->yieldContent('title'); ?> &mdash; STISIPOL Candradimuka Palembang (Kelas Karyawan)</title>
    <meta property="og:title" content="STISIPOL Candradimuka (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="STISIPOL Candradimuka (Kelas Karyawan)">
    <meta property="og:image" content="https://stisipolcandradimuka.info/images/background/hero1.png">
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description" content="STISIPOL Candradimuka menawarkan program S1 Kesejahteraan Sosial & Ilmu Politik, S1 Ilmu Komunikasi & Ilmu Administrasi Negara dengan biaya kuliah mulai dari Rp 300.000 per bulan. Dapatkan pendidikan berkualitas dengan kurikulum berbasis praktik dan akademik yang relevan. Bergabunglah dengan kami untuk membangun masa depan yang lebih cerah.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="STISIPOL Candradimuka (Kelas Karyawan) (Kelas Karyawan)">
    <meta name="twitter:description" content="Program Kelas Karyawan STISIPOL Candradimuka dirancang untuk para profesional yang ingin melanjutkan pendidikan S1 Kesejahteraan Sosial & Ilmu Politik, S1 Ilmu Komunikasi & Ilmu Administrasi Negara. Dengan jadwal fleksibel dan biaya kuliah terjangkau mulai dari Rp 300.000 per bulan, kami mendukung keseimbangan antara kerja dan studi. Dapatkan pendidikan berkualitas tanpa mengganggu karier Anda. Bergabunglah sekarang dan tingkatkan prospek masa depan Anda bersama STISIPOL Candradimuka!" />
    <meta name="twitter:domain" content="   ">
    <meta name="twitter:image:src" content="https://stisipolcandradimuka.info/images/background/hero1.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="STISIPOL Candradimuka | Kuliah Karyawan (K2)" />

    <link rel="apple-touch-icon" sizes="57x57" href="/images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="/images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="/images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="/images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="/images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="/images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"  href="/images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="/images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/images/favicons/favicon-16x16.png">
    <link rel="manifest" href="/images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="/images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">

    
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@400;600&family=DM+Sans:wght@400;700&display=swap" rel="stylesheet">
    <link href="<?php echo e(asset('css/app.css')); ?>" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css" />
    <link href="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.css" rel="stylesheet">

    <style>
        /* FIX TOTAL DOUBLE SCROLLBAR */
        html {
            overflow: -moz-scrollbars-none;
            -ms-overflow-style: none; /* IE and Edge */
            scrollbar-width: none; /* Firefox (untuk menghilangkan scrollbar di level html) */
            height: 100%;
            margin: 0;
            padding: 0;
        }

        html::-webkit-scrollbar {
            display: none; /* Chrome, Safari, Opera */
        }

        body {
            /* Scrollbar hanya boleh ada di sini */
            overflow-y: auto; 
            overflow-x: hidden !important;
            min-height: 100%;
            margin: 0;
            padding: 0;
            position: relative;
            -webkit-overflow-scrolling: touch;
        }

        /* Container utama tidak boleh punya scroll sendiri */
        main {
            overflow: visible !important;
            display: block;
            width: 100%;
        }

        /* Mencegah tombol WA merusak lebar layar */
        .whatsapp-button-container {
            pointer-events: none;
        }
        .whatsapp-button-container a, .whatsapp-button-container div {
            pointer-events: auto;
        }
    </style>

    <?php echo $__env->yieldPushContent('prpend-style'); ?>
    <?php echo $__env->yieldPushContent('addon-style'); ?>
</head>

<body class="antialiased">

    
    <?php echo $__env->make('Frontend.Template.navbar', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>

    
    <main>
        <?php echo $__env->yieldContent('content'); ?>
    </main>

    
    <div class="whatsapp-button-container fixed flex flex-row items-center bottom-4 right-4 z-[9999] md:bottom-10 md:right-10">
        <div style="color:#fff;"
            class="slide-text whatsapp-button hidden md:flex overflow-hidden shadow-2xl transition-all duration-500 ease-in-out bg-[#40C351] h-[45px] items-center px-4 font-poppins text-white rounded-full mr-2">
            <span class="whatsapp-button-text text-sm">ingin bertanya ? yuk di click !</span>
        </div>

        <a href="https://wa.me/6289504586704?text=Halo%20Admin%2C%20saya%20mau%20bertanya" 
            target="_blank" rel="noopener noreferrer" class="hover:scale-110 transition-transform">
            <img src="<?php echo e(asset('images/logo/wa.jpg')); ?>" alt="WhatsApp" class="w-12 h-12 md:w-[70px] md:h-[70px] rounded-full shadow-lg">
        </a>
    </div>

    
    <?php echo $__env->make('Frontend.Template.footer', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>

    
    <script src="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.js"></script>
    <script src="<?php echo e(asset('./js/app.js')); ?>"></script>

    <?php echo $__env->yieldPushContent('prpend-script'); ?>
    <?php echo $__env->yieldPushContent('addon-script'); ?>

    <script>
        AOS.init({ once: true });
        // Disable Right Click
        document.addEventListener('contextmenu', function(e) { e.preventDefault(); });
    </script>
</body>
</html><?php /**PATH /home/edunesiaserver/public_html/K2/WEB_KAMPUS/WEB_TEMPLATE/Merah-Kuning/resources/views/Frontend/Layouts/app.blade.php ENDPATH**/ ?>