<div class="md:h-[827px] h-auto flex flex-col items-center md:flex-row justify-center md:gap-x-[100px] py-[100px] md:py-[100px] px-4 md:px-0 bg-cover bg-no-repeat bg-right md:bg-center"
    style="background-image: url('{{ asset('./images/background/bg-sambutan.png') }}');">
    <div class="flex justify-center md:justify-start w-full md:w-auto flex-col items-center">
    <img src="{{ asset('./images/sambutan/sambutan.png') }}" data-aos="fade-up"
        class="h-auto md:w-[1000px] w-[300px] md:h-[500px] max-w-[450px]" style="border-radius:25px;" alt="{{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}">
    <p style="padding-top: 20px; font-size: 14px; color: #fff; text-align: center; font-family: 'Poppins', sans-serif;">
        <!-- <b>Dendi Afrizal, S.AB., M.Ak, </b> -->
    </p>
</div>
<div class="flex flex-col md:items-start justify-center items-center w-full md:w-[40%] mt-4 md:mt-0" data-aos="fade-up">
    <x-header-section subtext="SAMBUTAN KETUA {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}" subtext-color="#fff" title="" title-color="#fff" />
    
        <p class="text-justify font-dmsans mb-4 font-inter text-sm md:text-base text-white normal-case w-[80%]">
            Selamat datang di website Institut Agama Islam Sahid (INAIS), kampus yang mampu mencetak wirausahawan muda
            dan berakhlak mulia. INAIS adalah perguruan tinggi kebanggaan warga Bogor Barat di Kabupaten Bogor. Para
            pengajar di INAIS berasal dari dalam negeri (UI, IPB, UPI, UNJ dan UIN) maupun luar negeri (Universitas
            Sains Malaysia) yang memiliki dedikasi yang tinggi. Sistem perkuliahan menggunakan teknologi (High Tech)
            berpadu dengan sentuhan Islami (High Touch) membuat suasana kelas menyenangkan serta memotivasi mahasiswa
            untuk terus belajar dan mengasah keahlian sesuai minat dan bakat melalui program studi yang dipilih.</p>


    <a href="/sejarah-singkat" class="bg-yellow-400 hover:bg-primary font-medium py-2 px-4 rounded-md text-sm transition-all text-center text-white shadow-md">
        BACA SELENGKAPNYA
    </a>
</div>
</div>
