<div class="md:h-[827px] h-auto flex flex-col items-center md:flex-row justify-center md:gap-x-[100px] py-[100px] md:py-[100px] px-4 md:px-0 bg-cover bg-no-repeat bg-right md:bg-center"
    style="background-image: url('<?php echo e(asset('./images/background/bg-sambutan.png')); ?>');">
    <div class="flex justify-center md:justify-start w-full md:w-auto flex-col items-center">
    <img src="<?php echo e(asset('./images/sambutan/sambutan.png')); ?>" data-aos="fade-up"
        class="h-auto md:w-[1000px] w-[300px] md:h-[500px] max-w-[450px]" style="border-radius:25px;" alt="<?php echo e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia'); ?>">
    <p style="padding-top: 20px; font-size: 14px; color: #fff; text-align: center; font-family: 'Poppins', sans-serif;">
        <!-- <b>Dendi Afrizal, S.AB., M.Ak, </b> -->
    </p>
</div>
    <div class="flex flex-col md:items-start justify-center items-center w-full md:w-[40%] w-[100%] mt-4 md:mt-0"
        data-aos="fade-up">
        <?php if (isset($component)) { $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSection::class, ['subtext' => ' SAMBUTAN Ketua '.e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia').'','subtextColor' => '#fff','title' => '','titleColor' => '#fff']); ?>
<?php $component->withName('header-section'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe)): ?>
<?php $component = $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe; ?>
<?php unset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe); ?>
<?php endif; ?>
        <p class="text-justify font-dmsans mb-4 font-inter text-sm md:text-base  normal-case w-[80%]" style="color:#fff" >
Dengan mengucap syukur ke hadirat Allah Subhanahu Wata’ala, Sekolah Tinggi Manajemen Informatik Kalirejo hadir sebagai lembaga pendidikan tinggi yang berkomitmen membangun generasi unggul di bidang ekonomi syariah, yang berlandaskan nilai-nilai Islam dan mampu bersaing di tingkat global. Kami meyakini bahwa pendidikan syariah yang berkualitas harus mencakup penguasaan ilmu, pembentukan akhlak, serta kemampuan adaptif terhadap perubahan zaman. Oleh karena itu, STMIK Kalirejo mengembangkan kurikulum berbasis pemikiran kritis, inovasi, dan riset terapan yang relevan, serta menjalin kolaborasi dengan institusi pendidikan internasional. Dengan semangat kolaboratif dan visi global, kami siap mencetak lulusan yang tidak hanya profesional, tetapi juga menjadi agen perubahan bagi masyarakat, bangsa, dan umat.
        </p>
        
        <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/sejarah-singkat']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>BACA SELENGKAPNYA <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
    </div>
</div>
<?php /**PATH /home/edunesiaserver/public_html/K2/WEB_KAMPUS/WEB_TEMPLATE/Ijo-Kuning/resources/views/Frontend/landingpage/sambutan-section.blade.php ENDPATH**/ ?>