<!DOCTYPE html>
<html lang="id">

<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=0">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
            
    <title><?php echo $__env->yieldContent('title'); ?> &mdash; INSTITUT SAINS DAN TEKNOLOGI AL-KAMAL</title>
    
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@400;600&family=DM+Sans:wght@400;700&display=swap" rel="stylesheet">
    <link href="<?php echo e(asset('css/app.css')); ?>" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css" />
    <link href="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.css" rel="stylesheet">

    <style>
        /* FIX TOTAL DOUBLE SCROLLBAR */
        html {
            overflow: -moz-scrollbars-none;
            -ms-overflow-style: none; /* IE and Edge */
            scrollbar-width: none; /* Firefox (untuk menghilangkan scrollbar di level html) */
            height: 100%;
            margin: 0;
            padding: 0;
        }

        html::-webkit-scrollbar {
            display: none; /* Chrome, Safari, Opera */
        }

        body {
            /* Scrollbar hanya boleh ada di sini */
            overflow-y: auto; 
            overflow-x: hidden !important;
            min-height: 100%;
            margin: 0;
            padding: 0;
            position: relative;
            -webkit-overflow-scrolling: touch;
        }

        /* Container utama tidak boleh punya scroll sendiri */
        main {
            overflow: visible !important;
            display: block;
            width: 100%;
        }

        /* Mencegah tombol WA merusak lebar layar */
        .whatsapp-button-container {
            pointer-events: none;
        }
        .whatsapp-button-container a, .whatsapp-button-container div {
            pointer-events: auto;
        }
    </style>

    <?php echo $__env->yieldPushContent('prpend-style'); ?>
    <?php echo $__env->yieldPushContent('addon-style'); ?>
</head>

<body class="antialiased">

    
    <?php echo $__env->make('Frontend.Template.navbar', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>

    
    <main>
        <?php echo $__env->yieldContent('content'); ?>
    </main>

    
    <div class="whatsapp-button-container fixed flex flex-row items-center bottom-4 right-4 z-[9999] md:bottom-10 md:right-10">
        <div style="color:#fff;"
            class="slide-text whatsapp-button hidden md:flex overflow-hidden shadow-2xl transition-all duration-500 ease-in-out bg-[#40C351] h-[45px] items-center px-4 font-poppins text-white rounded-full mr-2">
            <span class="whatsapp-button-text text-sm">ingin bertanya ? yuk di click !</span>
        </div>

        <a href="https://wa.me/6289504586704?text=Halo%20Admin%2C%20saya%20mau%20bertanya" 
            target="_blank" rel="noopener noreferrer" class="hover:scale-110 transition-transform">
            <img src="<?php echo e(asset('images/logo/wa.jpg')); ?>" alt="WhatsApp" class="w-12 h-12 md:w-[70px] md:h-[70px] rounded-full shadow-lg">
        </a>
    </div>

    
    <?php echo $__env->make('Frontend.Template.footer', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>

    
    <script src="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.js"></script>
    <script src="<?php echo e(asset('./js/app.js')); ?>"></script>

    <?php echo $__env->yieldPushContent('prpend-script'); ?>
    <?php echo $__env->yieldPushContent('addon-script'); ?>

    <script>
        AOS.init({ once: true });
        // Disable Right Click
        document.addEventListener('contextmenu', function(e) { e.preventDefault(); });
    </script>
</body>
</html><?php /**PATH /home/edunesiaserver/public_html/K2/WEB_KAMPUS/JAKARTA/ISTA-ALKAMAL/WEB/resources/views/Frontend/Layouts/app.blade.php ENDPATH**/ ?>