@section('title', 'Sejarah')

@extends('Frontend.Layouts.app2')
@section('content')
<br><br>
    <x-header-section-page title="Sejarah  {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}" breadcrumb-home="Home" breadcrumb-current="Sejarah Singkat" />

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        {{-- <img src="{{ asset('./images/sambutan/petinggi.png') }}" data-aos="fade-up" class=" mb-5 w-full" alt=""> --}}

        <!-- Konten Teks -->
        <div data-aos="fade-up"
            class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px] bg-white shadow-xl shadow rounded-lg p-6">
            <p class="first-line:pl-5">
                Institut Agama Islam Sahid (INAIS) adalah perubahan status dari Sekolah Tinggi Agama Islam Terpadu (STAIT)
                Sahid. STAIT Sahid berdiri pada 15 Oktober 2008. Pada tahun 2015, STAIT Sahid berubah nama menjadi Institut
                Agama Islam Sahid disingkat INAIS. Perguruan tinggi ini merupakan bagian integral dari kawasan pendidikan
                Islam “Bumi Berkah Sahid Khusnul Khatimah, Padepokan Sahid Wisata Gunung Menyan.

            </p>
            <p>Kawasan pendidikan ini didirikan oleh Bapak Prof. Dr. H. Sukamdani Sahid Gitosarjono bersama
                Ibu Hj. Juliah Sukamdani dengan naungan Yayasan Wakaf Sahid Husnul Khatimah (YWSHK). Pada 27 Mei 2000,
                kawasan ini diresmikan penggunaannya dengan nama Pesantren Sahid Mandiri yang menaungi Madrasah Aliyah.
                Pesantren ini kemudian berubah nama menjadi Pondok Pesantren Moderen Sahid yang diresmikan oleh Menteri
                Agama RI Prof. Dr. KH. Tolhah Hasan. Kawasan pendidikan Islam ini sekarang terdiri dari satuan pendidikan
                mulai dari TK, MI, MTs, MA, SMK, Asrama Santri, hingga Perguruan Tinggi.
            </p>
            <p>STAIT memulai kegiatan akademiknya dengan menyelenggarakan satu jurusan, yaitu jurusan Ekonomi Syariat dengan
                jenjang Strata Satu (S1) yang terdiri dari dua program studi yakni Program Studi Perbankan Syariah dan
                Program Studi Bisnis dan Manajemen Syariah. STAIT terus berkembang dan pada 2009, didirikan Program Studi
                Komunikasi dan Penyiaran Islam (KPI). Tiga tahun kemudian, yakni tahun 2012, terbit izin penyelenggaraan
                Prodi Manajemen Pendidikan Islam (MPI) dan Prodi Pendidikan Guru Raudhatul Athfal atau PGRA. Pada tahun 2014
                menambah satu prodi yakni Prodi Pendidikan Guru Madrasah Ibtidaiyah atau PGMI.
            </p>
            <p>Perkembangan positif ini mengantarkan STAIT naik status dari sekolah tinggi menjadi institut. STAIT beralih
                status menjadi Institut Agama Islam Sahid (INAIS) atau Sahid Islamic Entrepreneurial University pada tanggal
                21 Mei 2015 (Surat Keputusan Direktur Jendral Pendidikan Agama Islam Nomor 2943 Tahun 2015). INAIS secara
                konsisten melaksanakan tugas pokok dan fungsi kependidikan tinggi yang mencakup Tridharma Perguruan Tinggi
                yakni melaksanakan Pengajaran, Penelitian dan Pengabdian kepada Masyarakat, khususnya di Wilayah Bogor Barat
                dan sekitarnya. Lembaga ini menyelenggarakan pendidikan pengajaran, penelitian dan pengabdian kepada
                masyarakat dengan mensinergikan Iman dan Taqwa (IMTAQ), serta ilmu pengetahuan, Teknologi dan Seni (IPTEKS)
                tanpa mengesampingkan sisi kebudayaan Indonesia.
            </p>
            <p>Sebagai pelaksana akademik, INAIS menempati posisi sangat strategik dalam rangka menyiapkan dan mencetak
                peserta didik menjadi anggota masyarakat yang mempunyai keahlian disiplin ilmu umum dan keagamaan, yang
                dapat diterapgunakan bagi kepentingan masyarakat Indonesia. Peran penting itu dapat terlaksana, karena
                perangkat keras dan lunaknya tersedia secara memadai. Oleh karenanya, INAIS terus mengembangkan kiprahnya
                dengan mendirikan program Pasca Sarjana. Pada tahun 2016, INAIS membuka program Strata Dua (S2) yakni Prodi
                Ekonomi dan Bisnis Syariah.
            </p>
            <p>INAIS telah menghasilkan lulusan-lulusan yang telah berkiprah baik di dunia pendidikan, dakwah dan menjadi
                tenaga professional di dunia keuangan dan bisnis syariah, serta menjadi wirausahawan yang sukses. Mereka
                telah mengabdikan ilmu dan keahliannya untuk agama, bangsa dan negara.
            </p>


        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">
                SEGERA DAFTAR
                </h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
            Bergabunglah bersama  {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }} dan Bangun Wawasan, Bentuk Karakter, Jadilah Pembawa Perubahan!
        </p>
            <x-button url="/pendaftaran">DAFTAR SEKARANG</x-button>
        </div>
    </div>
@endsection
