<?php $__env->startSection('title', 'VisiMisi'); ?>


<?php $__env->startSection('content'); ?>
<br><br>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => 'Visi Misi '.e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia').'','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'Visi Misi']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>

    <!-- Content Section -->
    <div class=" py-10 ">
        <div data-aos="fade-up" class="container mx-auto px-4 lg:px-16 space-y-12">
            <!-- Visi -->
            <!-- Visi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Visi</h2>
                <p data-aos="fade-up" class="text-gray-700 font-dmsans">
                    MENJADI PERGURUAN TINGGI ISLAM UNGGUL BERCIRIKAN KEWIRAUSAHAAN SYARIAH, TERKEMUKA DAN MANDIRI PADA TAHUN
                    2035​
                </p>
            </div>

            <!-- Misi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Misi</h2>
                <ul data-aos="fade-up" class="list-disc pl-5 space-y-3 text-gray-700 font-dmsans">
                    <li>
                        Melaksanakan pendidikan, penelitian dan pengabdian kepada masyarakat berdasarkan KKNI dan SNPT
                    </li>
                    <li>
                        Menyelenggarakan dan mengembangkan pendidikan bertaraf Internasional berbasis Islam dan
                        kewirausahaan syariah melalui proses pembelajaran kreatif, inovatif, efektif, dan menyenangkan
                        (PAKEM)
                    </li>
                    <li>
                        Mengembangkan, menciptakan dan menyebarluaskan ilmu pengetahuan, teknologi dan seni (IPTEKS)
                        inovatif, unggul dan berdaya saing yang bermanfaat bagi peningkatankualitas hidup dan kehidupan
                        sivitas akademik, alumni dan masyarakat
                    </li>
                    <li>
                        Melakukan pengembangan institusi secara berkelanjutan menuju terwujudnya SIIEC (Sahid Islamic
                        International Education Center)
                    </li>
                    <li>
                        Mengembangkan jaringandan kemitraan dengan berbagai lembaga pemerintah, satuan pendidikan dan
                        lembaga lainnya, serta dunia usaha baik di dalam maupun luar negeri.
                    </li>
                </ul>
            </div>

            <!-- Call to Action -->
            <div data-aos="fade-up" class="text-center shadow-xl">
                <div data-aos="fade-up" class="bg-accent py-8 rounded-lg" style="color:#fff">
                    <h2 data-aos="fade-up" class="text-xl font-poppins font-bold  mb-3">Bergabunglah dengan <?php echo e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia'); ?>

                    </h2>
                    <p data-aos="fade-up" class=" font-dmsans mb-5">Wujudkan impianmu dan raih masa depan cerah bersama <?php echo e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia'); ?></p>
                    <a href="/pendaftaran" data-aos="fade-up"
                        class="bg-yellow-400 hover:bg-primary font-medium py-2 px-3 rounded-md text-sm transition-all text-center text-white">
                        Daftar Sekarang
                    </a>
                </div>
            </div>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /home/edunesiaserver/public_html/K2/WEB_KAMPUS/WEB_TEMPLATE/Ungu-Kuning/resources/views/Frontend/visimisi.blade.php ENDPATH**/ ?>